@@ -46,6 +46,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ProvisioningTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ProvisioningGrpcTransport
 from .transports.grpc_asyncio import ProvisioningGrpcAsyncIOTransport
+from .transports.rest import ProvisioningRestTransport
 
 
 class ProvisioningClientMeta(type):
@@ -59,6 +60,7 @@ class ProvisioningClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[ProvisioningTransport]]
     _transport_registry["grpc"] = ProvisioningGrpcTransport
     _transport_registry["grpc_asyncio"] = ProvisioningGrpcAsyncIOTransport
+    _transport_registry["rest"] = ProvisioningRestTransport
 
     def get_transport_class(
         cls,
@@ -354,6 +356,9 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
             transport (Union[str, ProvisioningTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -449,6 +454,13 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             def sample_create_instance():
@@ -580,6 +592,13 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             def sample_delete_instance():
@@ -632,9 +651,6 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -699,6 +715,13 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import apigee_registry_v1
 
             def sample_get_instance():
@@ -1047,9 +1070,11 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
                 optionally specify a ``condition``, which is a logic
                 expression that further constrains the role binding
                 based on attributes about the request and/or target
-                resource. JSON Example.
+                resource.
 
-                .. code-block:: python
+                **JSON Example**
+
+                ::
 
                     {
                       "bindings": [
@@ -1166,9 +1191,11 @@ class ProvisioningClient(metaclass=ProvisioningClientMeta):
                 optionally specify a ``condition``, which is a logic
                 expression that further constrains the role binding
                 based on attributes about the request and/or target
-                resource. JSON Example.
+                resource.
 
-                .. code-block:: python
+                **JSON Example**
+
+                ::
 
                     {
                       "bindings": [
